OpenAQ python returns API responses as deserialized objects with helper methods to serialize the results to JSON. 


## Base Response Class


All response classes share some convenience methods for deserializing and serializing the response contents.

::: openaq.shared.responses._ResponseBase


## Resources 

__CountryBase__

::: openaq.shared.responses.CountryBase
    options:
      heading_level: 3
      show_root_heading: false
      show_bases: false
      show_source: false

__Country__

::: openaq.shared.responses.Country
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__InstrumentBase__

::: openaq.shared.responses.InstrumentBase
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Instrument__

::: openaq.shared.responses.Instrument
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__ManufacturerBase__

::: openaq.shared.responses.ManufacturerBase
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Manufacturer__

::: openaq.shared.responses.Manufacturer
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false



__Measurement__

::: openaq.shared.responses.Measurement
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Period__

::: openaq.shared.responses.Period
    options:
      heading_level: 4      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Summary__

::: openaq.shared.responses.Summary
    options:
      heading_level: 4      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false



__OwnerBase__

::: openaq.shared.responses.OwnerBase
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__Owner__

::: openaq.shared.responses.Owner
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__ParameterBase__

::: openaq.shared.responses.ParameterBase
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Parameter__

::: openaq.shared.responses.Parameter
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__ProviderBase__

::: openaq.shared.responses.ProviderBase
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__Provider__

::: openaq.shared.responses.Provider
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false





__SensorBase__

::: openaq.shared.responses.SensorBase
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Coordinates__

::: openaq.shared.responses.Coordinates
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__Datetime__

::: openaq.shared.responses.Datetime
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__OwnerEntity__

::: openaq.shared.responses.OwnerEntity
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__Location__

::: openaq.shared.responses.Location
    options:
      heading_level: 3
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


## API Responses

__Meta__ 

::: openaq.shared.responses.Meta
    options:
      heading_level: 3
      show_root_heading: false
      show_bases: false
      show_source: false

__CountriesResponse__

::: openaq.shared.responses.CountriesResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__InstrumentsResponse__

::: openaq.shared.responses.InstrumentsResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__LocationsResponse__

::: openaq.shared.responses.LocationsResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__ManufacturersResponse__

::: openaq.shared.responses.ManufacturersResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__MeasurementsResponse__

::: openaq.shared.responses.MeasurementsResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false


__OwnersResponse__

::: openaq.shared.responses.OwnersResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__ParametersResponse__

::: openaq.shared.responses.ParametersResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false

__ProvidersResponse__

::: openaq.shared.responses.ProvidersResponse
    options:
      heading_level: 3      
      members:
        -
      show_root_heading: false
      show_bases: false
      show_source: false